# eric7.EricWidgets.EricStretchableSpacer

Module implementing a stretchable spacer widget.

### Global Attributes

None

### Classes

EricStretchableSpacer | Class implementing a stretchable spacer widget.

### Functions

None

## EricStretchableSpacer

Class implementing a stretchable spacer widget.

### Derived from

QWidget

### Class Attributes

None

### Class Methods

None

### Methods

EricStretchableSpacer | Constructor

### Static Methods

None

#### EricStretchableSpacer (Constructor)

EricStretchableSpacer(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

Up